@@ -1,6 +1,6 @@
 package Dancer2;
 # ABSTRACT: Lightweight yet powerful web application framework
-$Dancer2::VERSION = '0.204001';
+$Dancer2::VERSION = '0.204002';
 use strict;
 use warnings;
 use List::Util  'first';
@@ -123,7 +123,7 @@ Dancer2 - Lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 DESCRIPTION
 
@@ -247,6 +247,7 @@ Returns the current runner. It is of type L<Dancer2::Core::Runner>.
     Bas Bloemsaat
     baynes
     Ben Hutton
+    biafra
     Blabos de Blebe
     Breno G. de Oliveira
     cdmalon
@@ -276,6 +277,7 @@ Returns the current runner. It is of type L<Dancer2::Core::Runner>.
     Gregor Herrmann
     Grzegorz Rożniecki
     Hobbestigrou
+    Hunter McMillen
     Ivan Bessarabov
     Ivan Kruglov
     JaHIY
