@@ -1,6 +1,6 @@
 # ABSTRACT: create new Dancer2 application
 package Dancer2::CLI::Command::gen;
-$Dancer2::CLI::Command::gen::VERSION = '0.204001';
+$Dancer2::CLI::Command::gen::VERSION = '0.204002';
 use strict;
 use warnings;
 
@@ -93,7 +93,7 @@ sub execute {
     _add_to_manifest_skip($app_path);
 
     if ( ! eval { require_module('YAML'); 1; } ) {
-        print <<NOYAML;
+        print <<'NOYAML';
 *****
 WARNING: YAML.pm is not installed.  This is not a full dependency, but is highly
 recommended; in particular, the scaffolded Dancer app being created will not be
@@ -291,7 +291,7 @@ Dancer2::CLI::Command::gen - create new Dancer2 application
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 AUTHOR
 
