@@ -1,6 +1,6 @@
 # ABSTRACT: encapsulation of Dancer2 packages
 package Dancer2::Core::App;
-$Dancer2::Core::App::VERSION = '0.204001';
+$Dancer2::Core::App::VERSION = '0.204002';
 use Moo;
 use Carp               qw<croak carp>;
 use Scalar::Util       'blessed';
@@ -10,6 +10,7 @@ use Safe::Isa;
 use Sub::Quote;
 use File::Spec;
 use Module::Runtime    'use_module';
+use List::Util         ();
 
 use Plack::App::File;
 use Plack::Middleware::FixMissingBodyInRedirect;
@@ -471,6 +472,13 @@ has destroyed_session => (
     clearer   => 'clear_destroyed_session',
 );
 
+sub find_plugin {
+    my ( $self, $name ) = @_;
+    my $plugin = List::Util::first { ref($_) eq $name } @{ $self->plugins };
+    $plugin or return;
+    return $plugin;
+}
+
 sub destroy_session {
     my $self = shift;
 
@@ -668,7 +676,6 @@ sub _build_default_config {
         environment    => $self->environment,
         appdir         => $self->location,
         public_dir     => $public,
-        static_handler => ( -d $public ),
         template       => 'Tiny',
         route_handlers => [
             [
@@ -994,6 +1001,7 @@ sub send_file {
 
     # if we're given a SCALAR reference, build a filehandle to it
     if ( ref $thing eq 'SCALAR' ) {
+        ## no critic qw(InputOutput::RequireCheckedOpen)
         open $fh, "<", $thing;
     }
 
@@ -1090,6 +1098,11 @@ sub BUILD {
 
 sub finish {
     my $self = shift;
+
+    # normalize some values that require calculations
+    defined $self->config->{'static_handler'}
+        or $self->config->{'static_handler'} = -d $self->config->{'public_dir'};
+
     $self->register_route_handlers;
     $self->compile_hooks;
 
@@ -1633,7 +1646,7 @@ Dancer2::Core::App - encapsulation of Dancer2 packages
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 DESCRIPTION
 
