@@ -1,6 +1,6 @@
 package Dancer2::Core::Request;
 # ABSTRACT: Interface for accessing incoming requests
-$Dancer2::Core::Request::VERSION = '0.204001';
+$Dancer2::Core::Request::VERSION = '0.204002';
 use strict;
 use warnings;
 use parent 'Plack::Request';
@@ -182,7 +182,7 @@ sub scheme {
 
 sub serializer { $_[0]->{'serializer'} }
 
-sub data { $_[0]->{'data'} ||= &deserialize }
+sub data { $_[0]->{'data'} ||= $_[0]->deserialize() }
 
 sub deserialize {
     my $self = shift;
@@ -680,7 +680,7 @@ Dancer2::Core::Request - Interface for accessing incoming requests
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 SYNOPSIS
 
