@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::Logger;
 # ABSTRACT: Role for logger engines
-$Dancer2::Core::Role::Logger::VERSION = '0.204001';
+$Dancer2::Core::Role::Logger::VERSION = '0.204002';
 use Dancer2::Core::Types;
 
 use Moo::Role;
@@ -127,7 +127,7 @@ sub format_message {
 
         my $cb = $chars_mapping->{$char};
         if ( !$cb ) {
-            Carp::carp "\%$char not supported.";
+            Carp::carp "%$char not supported.";
             return "-";
         }
         $cb->($char);
@@ -203,7 +203,7 @@ Dancer2::Core::Role::Logger - Role for logger engines
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 DESCRIPTION
 
