@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::Serializer;
 # ABSTRACT: Role for Serializer engines
-$Dancer2::Core::Role::Serializer::VERSION = '0.204001';
+$Dancer2::Core::Role::Serializer::VERSION = '0.204002';
 use Moo::Role;
 use Dancer2::Core::Types;
 use Scalar::Util 'blessed';
@@ -79,7 +79,7 @@ sub support_content_type {
     my ( $self, $ct ) = @_;
     return unless $ct;
 
-    my @toks = split ';', $ct;
+    my @toks = split /;/, $ct;
     $ct = lc( $toks[0] );
     return $ct eq $self->content_type;
 }
@@ -98,7 +98,7 @@ Dancer2::Core::Role::Serializer - Role for Serializer engines
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 DESCRIPTION
 
