@@ -1,9 +1,9 @@
 # ABSTRACT: Role for template engines
 
 package Dancer2::Core::Role::Template;
-$Dancer2::Core::Role::Template::VERSION = '0.204001';
+$Dancer2::Core::Role::Template::VERSION = '0.204002';
 use Dancer2::Core::Types;
-use Dancer2::FileUtils qw'path';
+use Dancer2::FileUtils 'path';
 use Carp 'croak';
 
 use Moo::Role;
@@ -233,7 +233,7 @@ Dancer2::Core::Role::Template - Role for template engines
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 DESCRIPTION
 
