@@ -1,6 +1,6 @@
 package Dancer2::Core::Route;
 # ABSTRACT: Dancer2's route handler
-$Dancer2::Core::Route::VERSION = '0.204001';
+$Dancer2::Core::Route::VERSION = '0.204002';
 use Moo;
 use Dancer2::Core::Types;
 use Carp 'croak';
@@ -114,7 +114,7 @@ sub match {
             # megasplat values are split on '/'
             if ($token_or_splat[$i] eq 'megasplat') {
                 $values[$i] = [
-                    defined $values[$i] ? split( '/' , $values[$i], -1 ) : ()
+                    defined $values[$i] ? split( m{/} , $values[$i], -1 ) : ()
                 ];
             }
             push @splat, $values[$i];
@@ -271,7 +271,7 @@ Dancer2::Core::Route - Dancer2's route handler
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 ATTRIBUTES
 
