@@ -1,6 +1,6 @@
 package Dancer2::Plugin;
 # ABSTRACT: base class for Dancer2 plugins
-$Dancer2::Plugin::VERSION = '0.204001';
+$Dancer2::Plugin::VERSION = '0.204002';
 use strict;
 use warnings;
 
@@ -83,6 +83,11 @@ sub execute_plugin_hook {
     $self->app->execute_hook( $full_name, @args );
 }
 
+sub find_plugin {
+    my ( $self, $name ) = @_;
+    return $self->app->find_plugin($name);
+}
+
 # both functions are there for D2::Core::Role::Hookable
 # back-compatibility. Aren't used
 sub supported_hooks { [] }
@@ -114,7 +119,7 @@ sub _p2_has_from_config {
     my $orig_default = $args{default} || sub{};
     $args{default} = sub {
         my $plugin = shift;
-        my $value = reduce { eval { $a->{$b} } } $plugin->config, split '\.', $config_name;
+        my $value = reduce { eval { $a->{$b} } } $plugin->config, split /\./, $config_name;
         return defined $value ? $value: $orig_default->($plugin);
     };
 
@@ -196,13 +201,13 @@ sub _exporter_app {
     # Otherwise you can only import from a plugin to an app,
     # but with this, you can import to anything
     # that has a DSL with an app, which translates to "also plugins"
-    my $app = eval("${caller}::app()") || eval { $caller->dsl->app }
+    my $app = eval("${caller}::app()") || eval { $caller->dsl->app } ## no critic qw(BuiltinFunctions::ProhibitStringyEval)
         or return; ## no critic
 
     return unless $app->can('with_plugin');
 
-    my $plugin = $app->with_plugin( "+" . $class );
-    $global->{plugin} = $plugin;
+    my $plugin = $app->with_plugin( '+' . $class );
+    $global->{'plugin'} = $plugin;
 
     return unless $class->can('keywords');
 
@@ -459,6 +464,7 @@ END
         my $dsl = $app_dsl_cb->();
 
         {
+            ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
             no strict 'refs';
             no warnings 'redefine';
             *{"${caller}::dsl"} = sub {$dsl};
@@ -619,7 +625,7 @@ Dancer2::Plugin - base class for Dancer2 plugins
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 SYNOPSIS
 
@@ -983,6 +989,27 @@ This does not export C<smiley()> into your application - it is only available
 from within your plugin. However, from the example above, you can wrap 
 DSL from other plugins and make it available from your plugin.
 
+=head2 Utilizing other plugins
+
+You can use the C<find_plugin> to locate other plugins loaded by the user,
+in order to use them, or their information, directly:
+
+    # MyApp.pm
+    use Dancer2;
+    use Dancer2::Plugin::Foo;
+    use Dancer2::Plugin::Bar;
+
+    # Dancer2::Plugin::Bar;
+    ...
+
+    sub my_keyword {
+        my $self = shift;
+        my $foo  = $self->find_plugin('Dancer2::Plugin::Foo')
+            or $self->dsl->send_error('Could not find Foo');
+
+        return $foo->foo_keyword(...);
+    }
+
 =head2 Hooks
 
 New plugin hooks are declared via C<plugin_hooks>.
