@@ -1,12 +1,12 @@
 # ABSTRACT: Template toolkit engine for Dancer2
 
 package Dancer2::Template::TemplateToolkit;
-$Dancer2::Template::TemplateToolkit::VERSION = '0.204001';
+$Dancer2::Template::TemplateToolkit::VERSION = '0.204002';
 use Moo;
-use Carp qw/croak/;
+use Carp qw<croak>;
 use Dancer2::Core::Types;
-use Dancer2::FileUtils qw'path';
-use Scalar::Util qw();
+use Dancer2::FileUtils qw<path>;
+use Scalar::Util ();
 use Template;
 
 with 'Dancer2::Core::Role::Template';
@@ -99,7 +99,7 @@ Dancer2::Template::TemplateToolkit - Template toolkit engine for Dancer2
 
 =head1 VERSION
 
-version 0.204001
+version 0.204002
 
 =head1 SYNOPSIS
 
